﻿using Syncfusion.SfSchedule.XForms;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using Xamarin.Forms;

namespace ResourceView
{
    public class SchedulerPageBehavior : Behavior<ContentPage>
    {
        SfSchedule schedule;
        protected override void OnAttachedTo(ContentPage bindable)
        {
            base.OnAttachedTo(bindable);
            this.schedule = bindable.Content.FindByName<SfSchedule>("schedule");
            var schedulerViewModel = new SchedulerViewModel();
            this.schedule.DataSource = schedulerViewModel.Events;
            this.schedule.ScheduleResources = schedulerViewModel.Chairs;
        }
    }
    public class SchedulerViewModel : INotifyPropertyChanged
    {
        /// <summary>
        /// current day meetings 
        /// </summary>
        private List<string> PatientList;

        /// <summary>
        /// color collection
        /// </summary>
        private List<Color> colorCollection;

        /// <summary>
        /// list of meeting
        /// </summary>
        private ObservableCollection<Event> events;

        /// <summary>
        /// name collection
        /// </summary>

        internal List<string> ChairCollection;

        /// <summary>
        /// resources
        /// </summary>
        private ObservableCollection<object> chairs;

        /// <summary>
        /// selected Resources
        /// </summary>
        private ObservableCollection<object> selectedChairs;

        public SchedulerViewModel()
        {
            this.events = new ObservableCollection<Event>();
            chairs = new ObservableCollection<object>();
            selectedChairs = new ObservableCollection<object>();
            this.InitializeDataForBookings();
            this.InitializeResources();
            this.BookingAppointments();
        }

        /// <summary>
        /// Property changed event handler
        /// </summary>
        public event PropertyChangedEventHandler PropertyChanged;

        #region ListOfMeeting

        /// <summary>
        /// Gets or sets list of meeting
        /// </summary>
        public ObservableCollection<Event> Events
        {
            get
            {
                return this.events;
            }

            set
            {
                this.events = value;
                this.RaiseOnPropertyChanged("Events");
            }
        }
        #endregion

        public ObservableCollection<object> Chairs
        {
            get
            {
                return chairs;
            }

            set
            {
                chairs = value;
                this.RaiseOnPropertyChanged("Chairs");
            }
        }


        public ObservableCollection<object> SelectedChairs
        {
            get
            {
                return selectedChairs;
            }

            set
            {
                selectedChairs = value;
                this.RaiseOnPropertyChanged("selectedChairs");
            }
        }

        private void InitializeResources()
        {
            Random random = new Random();
            for (int i = 0; i < 4; i++)
            {
                Chairs.Add(new Clinic()
                {
                    Name = ChairCollection[i],
                    Color = colorCollection[i],
                    Id = i.ToString(),
                });
            }

            this.SelectedChairs.Add(Chairs[0]);
        }

        #region BookingAppointments

        /// <summary>
        /// Method for booking appointments.
        /// </summary>
        private void BookingAppointments()
        {

            Event meeting = new Event();
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(10),
                To = DateTime.Now.Date.AddHours(11),
                EventName = this.PatientList[0],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(12),
                To = DateTime.Now.Date.AddHours(13),
                EventName = this.PatientList[3],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(15),
                To = DateTime.Now.Date.AddHours(16),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(9),
                To = DateTime.Now.Date.AddHours(10),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(14),
                To = DateTime.Now.Date.AddHours(15),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(11),
                To = DateTime.Now.Date.AddHours(12),
                EventName = this.PatientList[1],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(14),
                To = DateTime.Now.Date.AddHours(15),
                EventName = this.PatientList[4],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(16),
                To = DateTime.Now.Date.AddHours(17),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(9),
                To = DateTime.Now.Date.AddHours(10),
                EventName = this.PatientList[9],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });




            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddHours(13),
                To = DateTime.Now.Date.AddHours(14),
                EventName = this.PatientList[8],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.AddDays(1).AddHours(9),
                To = DateTime.Now.Date.AddDays(1).AddHours(10),
                EventName = this.PatientList[8],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(11),
                To = DateTime.Now.Date.AddDays(1).AddHours(12),
                EventName = this.PatientList[0],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.AddDays(1).AddHours(15),
                To = DateTime.Now.Date.AddDays(1).AddHours(16),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(13),
                To = DateTime.Now.Date.AddDays(1).AddHours(14),
                EventName = this.PatientList[4],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(16),
                To = DateTime.Now.Date.AddDays(1).AddHours(17),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.AddDays(1).AddHours(10),
                To = DateTime.Now.Date.AddDays(1).AddHours(11),
                EventName = this.PatientList[9],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(12),
                To = DateTime.Now.Date.AddDays(1).AddHours(13),
                EventName = this.PatientList[1],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.AddDays(1).AddHours(16),
                To = DateTime.Now.Date.AddDays(1).AddHours(17),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(14),
                To = DateTime.Now.Date.AddDays(1).AddHours(15),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(1).AddHours(15),
                To = DateTime.Now.Date.AddDays(1).AddHours(16),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });




            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(10),
                To = DateTime.Now.Date.AddDays(2).AddHours(11),
                EventName = this.PatientList[1],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(12),
                To = DateTime.Now.Date.AddDays(2).AddHours(13),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(9),
                To = DateTime.Now.Date.AddDays(2).AddHours(10),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(15),
                To = DateTime.Now.Date.AddDays(2).AddHours(16),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(11),
                To = DateTime.Now.Date.AddDays(2).AddHours(12),
                EventName = this.PatientList[2],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(13),
                To = DateTime.Now.Date.AddDays(2).AddHours(14),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(10),
                To = DateTime.Now.Date.AddDays(2).AddHours(11),
                EventName = this.PatientList[0],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(2).AddHours(16),
                To = DateTime.Now.Date.AddDays(2).AddHours(17),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(11),
                To = DateTime.Now.Date.AddDays(3).AddHours(12),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(10),
                To = DateTime.Now.Date.AddDays(3).AddHours(11),
                EventName = this.PatientList[1],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(15),
                To = DateTime.Now.Date.AddDays(3).AddHours(16),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(12),
                To = DateTime.Now.Date.AddDays(3).AddHours(13),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(9),
                To = DateTime.Now.Date.AddDays(3).AddHours(10),
                EventName = this.PatientList[9],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(12),
                To = DateTime.Now.Date.AddDays(3).AddHours(13),
                EventName = this.PatientList[8],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(11),
                To = DateTime.Now.Date.AddDays(3).AddHours(12),
                EventName = this.PatientList[2],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(16),
                To = DateTime.Now.Date.AddDays(3).AddHours(17),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(13),
                To = DateTime.Now.Date.AddDays(3).AddHours(14),
                EventName = this.PatientList[0],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(3).AddHours(11),
                To = DateTime.Now.Date.AddDays(3).AddHours(12),
                EventName = this.PatientList[1],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(14),
                To = DateTime.Now.Date.AddDays(4).AddHours(15),
                EventName = this.PatientList[9],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(10),
                To = DateTime.Now.Date.AddDays(4).AddHours(11),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[0] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(11),
                To = DateTime.Now.Date.AddDays(4).AddHours(12),
                EventName = this.PatientList[7],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(13),
                To = DateTime.Now.Date.AddDays(4).AddHours(14),
                EventName = this.PatientList[3],
                Resources = new ObservableCollection<object> { (chairs[1] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(9),
                To = DateTime.Now.Date.AddDays(4).AddHours(10),
                EventName = this.PatientList[2],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(11),
                To = DateTime.Now.Date.AddDays(4).AddHours(12),
                EventName = this.PatientList[4],
                Resources = new ObservableCollection<object> { (chairs[2] as Clinic).Id },
            });


            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(13),
                To = DateTime.Now.Date.AddDays(4).AddHours(14),
                EventName = this.PatientList[8],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });

            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(14),
                To = DateTime.Now.Date.AddDays(4).AddHours(15),
                EventName = this.PatientList[5],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });
            Events.Add(new Event()
            {
                From = DateTime.Now.Date.AddDays(4).AddHours(16),
                To = DateTime.Now.Date.AddDays(4).AddHours(17),
                EventName = this.PatientList[6],
                Resources = new ObservableCollection<object> { (chairs[3] as Clinic).Id },
            });
        }

        #endregion BookingAppointments

        #region InitializeDataForBookings

        /// <summary>
        /// Method for initialize data bookings.
        /// </summary>
        private void InitializeDataForBookings()
        {
            this.PatientList = new List<string>();
            this.PatientList.Add("Patient 1");
            this.PatientList.Add("Patient 2");
            this.PatientList.Add("Patient 3");
            this.PatientList.Add("Patient 4");
            this.PatientList.Add("Patient 5");
            this.PatientList.Add("Patient 6");
            this.PatientList.Add("Patient 7");
            this.PatientList.Add("Patient 8");
            this.PatientList.Add("Patient 9");
            this.PatientList.Add("Patient 10");

            this.colorCollection = new List<Color>();
            this.colorCollection.Add(Color.GreenYellow);
            this.colorCollection.Add(Color.Red);
            this.colorCollection.Add(Color.Pink);
            this.colorCollection.Add(Color.Green);

            this.ChairCollection = new List<string>();
            this.ChairCollection.Add("Chair 1");
            this.ChairCollection.Add("Chair 2");
            this.ChairCollection.Add("Chair 3");
            this.ChairCollection.Add("Chair 4");
        }

        #endregion InitializeDataForBookings

        #region Property Changed Event

        /// <summary>
        /// Invoke method when property changed
        /// </summary>
        /// <param name="propertyName">property name</param>
        private void RaiseOnPropertyChanged(string propertyName)
        {
            this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));
        }

        #endregion
    }
}
